@@ -23,8 +23,16 @@ __all__ = [
     'icon_fromfile',
     'row',
     'file',
+    'app',
+    'image_from_mpl',
+    'image_from_file',
+    'image_from_url',
 ]
 
+image_from_mpl= app.image_from_mpl
+image_from_file = app.image_from_file
+image_from_url = app.image_from_url
+
 box = app.box
 add_srcipt = app.add_srcipt
 dataTable = app.dataTable
