@@ -17,13 +17,20 @@ from .auto_create._echart import _EChart
 class EChart(_EChart):
     def __init__(
             self,
-            data_info: TDataFrameInfo,
+            data_info: Optional[TDataFrameInfo]=None,
     ) -> None:
         super().__init__()
-        self._data_id = data_info
+        self._data_info = data_info
         self._series = []
         self.update_styles(height='400px', width='100%')
         self._filter_watch_infos: List[TChartFilterWatch] = []
+        (
+            self.set_option('dataset',{
+                    'dimensions': [],
+                        'source': {}
+            })
+            .set_option('xAxis',{}).set_option('yAxis',{})
+        )
 
     @property
     def utils(self, ):
@@ -58,19 +65,17 @@ class EChart(_EChart):
 
     def _ex_get_react_data(self):
         data = super()._ex_get_react_data()
+
+        info_id = None
+        if self._data_info:
+            info_id = self._data_info.id
+
         data.update({
             'dataInfo': {
-                'id': self._data_id.id
+                'id': info_id
             },
-            'option': {
-                'tooltip': {},
-                'dataset': {
-                    'dimensions': [],
-                    'source': {}
-                },
-                'xAxis': {},
-                'yAxis': {},
-                'series': []
+            'option':{
+
             },
             'clickInfo': {},
         })
@@ -81,6 +86,11 @@ class Helper():
     def __init__(self, echart: EChart) -> None:
         self._echart = echart
 
+    def use_from_option_dict(self,option:Dict):
+        for key,value in option.items():
+            self._echart.set_option(key,value)
+        return self
+
     def use_pie(self, itemName: str, value: str):
         self._echart.set_option('series', [{
             'type': 'pie',
