@@ -31,4 +31,6 @@ def df2array_dict(df: pd.DataFrame):
 
 
 def value2code(v: Any):
+    if v is None:
+        return 'null'
     return str(v) if not isinstance(v, str) else f"'{v}'"
\ No newline at end of file
